@@ -4,7 +4,7 @@ test_that("get_related_videos runs successfully", {
 
   skip_on_cran()
 
-  google_token <- readRDS("token_file.rds")$google_token
+  google_token <- readRDS("token_file.rds.enc")$google_token
   options(google_token = google_token)
 
   get_info <- get_related_videos(video_id = "yJXTXN4xrI8")
