@@ -6,7 +6,7 @@ test_that("list_channel_sections runs successfully", {
 
   skip_on_cran()
 
-  google_token <- readRDS("token_file.rds")$google_token
+  google_token <- readRDS("token_file.rds.enc")$google_token
   options(google_token = google_token)
 
   get_info <- list_channel_sections(c(channel_id = "UCRw8bIz2wMLmfgAgWm903cA"))
@@ -18,7 +18,7 @@ test_that("list_my_channel runs successfully", {
 
   skip_on_cran()
 
-  google_token <- readRDS("token_file.rds")$google_token
+  google_token <- readRDS("token_file.rds.enc")$google_token
   options(google_token = google_token)
 
   get_info <- list_my_channel()
